// This script evaluates the gas outcome on given lever states. 
// It then turns on/off the effects and finally desintegrates the elementals when the conditions are met
// and also merges the crystal with the elemental essences when those conditions are met.

#include"scripts//functions//smartFadeIn.c"
#include"scripts//functions//fadeOutByWorldID.c"
#include"scripts//functions//fadeInByWorldID.c"
#include"scripts//functions//removeByWorldID.c"
#include"scripts//crystal_cave_element//addKillRoomEffects.c"
#include"scripts//crystal_cave_element//addSocketRoomNorthEffects.c"
#include"scripts//crystal_cave_element//addSocketRoomSouthEffects.c"

int numberOfActiveLeftLevers()
{
  float tmp = state_lever_left1 + state_lever_left2 + state_lever_left3; 
  if(tmp == 0)
    return 1;
  return tmp;
}

int numberOfActiveRightLevers()
{
  float tmp = state_lever_right1 + state_lever_right2 + state_lever_right3;
  if(tmp == 0)
    return 1;
  return tmp;
}

//DebugMessage("manage pipeline");

int k = 0;

// gas outcome variables

gas_amount_ice_at_kill = 0.0;
gas_amount_fire_at_kill = 0.0;
gas_amount_ice_at_socket = 0.0;
gas_amount_fire_at_socket = 0.0;
gas_amount_ice_at_secret = 0.0;
gas_amount_fire_at_secret = 0.0;


// Determine outcome of gas taking into account the levers for sources and pipes.
 
//gas_amount_ice_at_kill = fullTankIce() * float(state_source2) * state_lever_right1 / float(numberOfActiveRightLevers());
gas_amount_ice_at_kill = float(state_source2) * state_lever_right1 / float(numberOfActiveRightLevers());
gas_amount_ice_at_socket = float(state_source2) * state_lever_right2 / float(numberOfActiveRightLevers());
gas_amount_ice_at_secret = float(state_source2) * state_lever_right3 / float(numberOfActiveRightLevers());

gas_amount_fire_at_secret = float(state_source1) * state_lever_left1 / float(numberOfActiveLeftLevers());
gas_amount_fire_at_socket = float(state_source1) * state_lever_left2 / float(numberOfActiveLeftLevers());
gas_amount_fire_at_kill = float(state_source1) * state_lever_left3 / float(numberOfActiveLeftLevers());

//DebugMessage(10.0, " ", gas_amount_ice_at_kill, " ", gas_amount_fire_at_kill, " ", gas_amount_ice_at_socket, " ", gas_amount_fire_at_socket, " ", gas_amount_ice_at_secret, " ", gas_amount_fire_at_secret); 



// control effects at pentagram_ice kill
if( gas_amount_ice_at_kill > 0 &&  gas_amount_fire_at_kill > 0 )
{
  //DebugMessage(10.0, "branch 1");
  addKillRoomEffects(mix_effect ,"gas_mix_ice", S_GasMix, -40);
  removeByWorldID("gas_ice1");
  removeByWorldID("gas_ice11");
  removeByWorldID("gas_fire1");
  removeByWorldID("gas_fire11");
}
else if( gas_amount_ice_at_kill > 0 )
{
  //  DebugMessage(10.0, "branch 2");
  if( gas_amount_ice_at_kill > 0.9 )
    {
      //DebugMessage(10.0, "branch 21");
	  addKillRoomEffects(ice_effect_strong ,"gas_ice1", S_GasIce, 0);
      removeByWorldID("gas_ice11");
      removeByWorldID("gas_fire1");
      removeByWorldID("gas_fire11");
      removeByWorldID("gas_mix_ice");
    }
  else
    {
      //      DebugMessage(10.0, "branch 22");
      addKillRoomEffects(ice_effect_weak ,"gas_ice11", S_GasIce, 0);
      removeByWorldID("gas_ice1");
      removeByWorldID("gas_fire1");
      removeByWorldID("gas_fire11");
      removeByWorldID("gas_mix_ice");
    }
    }
else if ( gas_amount_fire_at_kill > 0  ) 
{
    if( gas_amount_fire_at_kill > 0.9 )
      {
	//	DebugMessage(10.0, "branch 31");
	addKillRoomEffects(fire_effect_strong ,"gas_fire1", S_GasFire, 0);
	removeByWorldID("gas_ice1");
	removeByWorldID("gas_ice11");
	removeByWorldID("gas_fire11");
	removeByWorldID("gas_mix_ice");
      }
    else
    {
      //     DebugMessage(10.0, "branch 32");
      addKillRoomEffects(fire_effect_weak ,"gas_fire11", S_GasFire, 0);
      removeByWorldID("gas_ice11");
      removeByWorldID("gas_ice1");
      removeByWorldID("gas_fire1");
      removeByWorldID("gas_mix_ice");
    }
}
else
{
  //  DebugMessage(10.0, "branch 4");
  removeByWorldID("gas_ice1");
  removeByWorldID("gas_ice11");
  removeByWorldID("gas_fire1");
  removeByWorldID("gas_fire11");
  removeByWorldID("gas_mix_ice");
}





// control effects at pentagram_fire (socket)
if( gas_amount_ice_at_socket > 0 )
{
  //  DebugMessage(10.0, "branch 2;
  if( gas_amount_ice_at_socket > 0.9 )
    {
      //      DebugMessage(10.0, "branch 21;
      addSocketRoomNorthEffects(ice_effect_strong ,"gas_ice2", S_GasIce);
      removeByWorldID("gas_ice12");
    }
  else
    {
      //      DebugMessage(10.0, "branch 22;
      addSocketRoomNorthEffects(ice_effect_weak ,"gas_ice12", S_GasIce);
      removeByWorldID("gas_ice2");
    }
}
else
{
	removeByWorldID("gas_ice12");
	removeByWorldID("gas_ice2");
}
if ( gas_amount_fire_at_socket > 0  ) 
{
    if( gas_amount_fire_at_socket > 0.9 )
      {
	//	DebugMessage(10.0, "branch 31;
	addSocketRoomSouthEffects(fire_effect_strong ,"gas_fire2", S_GasIce);;
	removeByWorldID("gas_fire12");
      }
    else
    {
      //      DebugMessage(10.0, "branch 32;
      addSocketRoomSouthEffects(fire_effect_weak ,"gas_fire12", S_GasFire);
      removeByWorldID("gas_fire2");
    }
}
else
{
	removeByWorldID("gas_fire12");
	removeByWorldID("gas_fire2");
}





if(fire_elemental_inkillroom == 1 && gas_amount_ice_at_kill == 1.0 && gas_amount_fire_at_kill == 0.0 && fire_elemental_killed != 1)
{
  fire_elemental_killed = 1;
  RequestRunScript("scripts//crystal_cave_element//seq//seq_kill_fire.c");
}
else if(gas_amount_ice_at_kill == 1.0 && gas_amount_fire_at_kill == 0.0 && fire_elemental_killed != 1 && rem_kill_fire == 0)
{
  rem_kill_fire++;
  RequestRunScript("scripts//crystal_cave_element//seq//seq_kill_empty.c");
}

if(ice_elemental_inkillroom == 1 && gas_amount_fire_at_kill == 1.0 && gas_amount_ice_at_kill == 0.0 && ice_elemental_killed != 1)
{
  ice_elemental_killed = 1;
  RequestRunScript("scripts//crystal_cave_element//seq//seq_kill_ice.c");
}
else if(gas_amount_fire_at_kill == 1.0 && gas_amount_ice_at_kill == 0.0 && ice_elemental_killed != 1 && rem_kill_ice == 0)
{
  rem_kill_ice++;
  RequestRunScript("scripts//crystal_cave_element//seq//seq_kill_empty.c");
}

if( items_inserted == 3 && gas_amount_fire_at_socket == 1.0 && gas_amount_ice_at_socket == 1.0)
{
  RequestRunScript("scripts//crystal_cave_element//seq//seq_melt_crystal.c");
}
else if( gas_amount_fire_at_socket == 1.0 && gas_amount_ice_at_socket == 1.0 &&  rem_socket == 0)
{
  rem_socket++;
  RequestRunScript("scripts//crystal_cave_element//seq//seq_melt_empty.c");
}






// check conditions for opening the secret door

if ( gas_amount_ice_at_secret > 0.9 && gas_amount_fire_at_secret > 0.9 && state_secret == 0 )
{
  state_secret = 1;
 
  //UseWall(-1, GetWall("door_secret"));
  SetWallOpacity(GetWall("secret_wall"), 0);
  FadeOutWall(GetWall("secret_wall"), 3.0); 
  FadeInWall(GetWall("corner5"), 3.0);
  FadeInWall(GetWall("corner6"), 3.0);
  FadeInWall(GetWall("corner7"), 3.0);
  FadeInWall(GetWall("corner8"), 3.0);

  
  SetWallSolid(GetWall("secret_wall"), 0.0);
  

  FadeInLight(GetLight("light_secret"), 3.0);

}



